@@ -45,3 +45,6 @@ class FileType(ABC):
 
     def __eq__(self, other):
         return self.name == other.name
+
+    def __hash__(self):
+        return hash(self.name)
