@@ -8,6 +8,7 @@ import pandas as pd
 from airflow.decorators.base import DecoratedOperator
 
 from astro.airflow.datasets import kwargs_with_datasets
+from astro.dataframes.pandas import PandasDataframe
 
 try:
     from airflow.decorators.base import TaskDecorator, task_decorator_factory
@@ -36,8 +37,7 @@ def _get_dataframe(
     df = convert_columns_names_capitalization(
         df=df, columns_names_capitalization=columns_names_capitalization
     )
-
-    return df
+    return PandasDataframe.from_pandas_df(df)
 
 
 def load_op_arg_table_into_dataframe(
@@ -215,7 +215,7 @@ class DataframeOperator(AstroSQLBaseOperator, DecoratedOperator):
             )
         return function_output
 
-    def get_openlineage_facets(self, task_instance):  # skipcq: PYL-W0613
+    def get_openlineage_facets_on_complete(self, task_instance):  # skipcq: PYL-W0613
         """
         Collect the input, output, job and run facets for DataframeOperator
         """
@@ -223,20 +223,15 @@ class DataframeOperator(AstroSQLBaseOperator, DecoratedOperator):
             BaseFacet,
             DataSourceDatasetFacet,
             OpenlineageDataset,
+            OperatorLineage,
             OutputStatisticsOutputDatasetFacet,
             SchemaDatasetFacet,
             SchemaField,
         )
-        from astro.lineage.extractor import OpenLineageFacets
 
         output_dataset: list[OpenlineageDataset] = []
 
         if self.output_table and self.output_table.openlineage_emit_temp_table_event():  # pragma: no cover
-            output_uri = (
-                f"{self.output_table.openlineage_dataset_namespace()}"
-                f"/{self.output_table.openlineage_dataset_name()}"
-            )
-
             output_dataset = [
                 OpenlineageDataset(
                     namespace=self.output_table.openlineage_dataset_namespace(),
@@ -252,7 +247,9 @@ class DataframeOperator(AstroSQLBaseOperator, DecoratedOperator):
                                 )
                             ]
                         ),
-                        "dataSource": DataSourceDatasetFacet(name=self.output_table.name, uri=output_uri),
+                        "dataSource": DataSourceDatasetFacet(
+                            name=self.output_table.name, uri=self.output_table.openlingeage_dataset_uri()
+                        ),
                         "outputStatistics": OutputStatisticsOutputDatasetFacet(
                             rowCount=self.output_table.row_count,
                         ),
@@ -262,7 +259,7 @@ class DataframeOperator(AstroSQLBaseOperator, DecoratedOperator):
 
         run_facets: dict[str, BaseFacet] = {}
         job_facets: dict[str, BaseFacet] = {}
-        return OpenLineageFacets(
+        return OperatorLineage(
             inputs=[], outputs=output_dataset, run_facets=run_facets, job_facets=job_facets
         )
 
