@@ -62,7 +62,7 @@ class ExportFileOperator(AstroSQLBaseOperator):
         else:
             raise FileExistsError(f"{self.output_file.path} file already exists.")
 
-    def get_openlineage_facets(self, task_instance):  # skipcq: PYL-W0613
+    def get_openlineage_facets_on_complete(self, task_instance):  # skipcq: PYL-W0613
         """
         Collect the input, output, job and run facets for export file operator
         """
@@ -72,26 +72,23 @@ class ExportFileOperator(AstroSQLBaseOperator):
             DataQualityMetricsInputDatasetFacet,
             DataSourceDatasetFacet,
             OpenlineageDataset,
+            OperatorLineage,
             OutputStatisticsOutputDatasetFacet,
             SchemaDatasetFacet,
             SchemaField,
         )
-        from astro.lineage.extractor import OpenLineageFacets
         from astro.lineage.facets import ExportFileFacet
 
         input_dataset: list[OpenlineageDataset] = []
         if isinstance(self.input_data, BaseTable) and self.input_data.openlineage_emit_temp_table_event():
-            input_uri = (
-                f"{self.input_data.openlineage_dataset_namespace()}"
-                f"://{self.input_data.openlineage_dataset_name()}"
-            )
             input_dataset = [
                 OpenlineageDataset(
                     namespace=self.input_data.openlineage_dataset_namespace(),
                     name=self.input_data.openlineage_dataset_name(),
                     facets={
                         "dataSource": DataSourceDatasetFacet(
-                            name=self.input_data.openlineage_dataset_name(), uri=input_uri
+                            name=self.input_data.openlineage_dataset_name(),
+                            uri=self.input_data.openlingeage_dataset_uri(),
                         ),
                         "schema": SchemaDatasetFacet(
                             fields=[
@@ -108,8 +105,7 @@ class ExportFileOperator(AstroSQLBaseOperator):
                 )
             ]
         output_uri = (
-            f"{self.output_file.openlineage_dataset_namespace}"
-            f"://{self.output_file.openlineage_dataset_name}"
+            f"{self.output_file.openlineage_dataset_namespace}" f"{self.output_file.openlineage_dataset_name}"
         )
         output_dataset = [
             OpenlineageDataset(
@@ -136,7 +132,7 @@ class ExportFileOperator(AstroSQLBaseOperator):
         run_facets: dict[str, BaseFacet] = {}
         job_facets: dict[str, BaseFacet] = {}
 
-        return OpenLineageFacets(
+        return OperatorLineage(
             inputs=input_dataset, outputs=output_dataset, run_facets=run_facets, job_facets=job_facets
         )
 
